DdSort class

折上折排序

Constructors

DdSort()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

commissionHighToLow → String
佣金比例从高到低
final
couponHighToLow → String
领券量从高到低
final
defaultSort → String
综合排序
final
priceHighToLow → String
价格(券后价)从高到低
final
priceLowToHigh → String
价格(券后价)从低到高
final
salesHighToLow → String
销量从高到低
final
timeHighToLow → String
商品上架时间从高到低
final