Arguments class

Constructors

Arguments({required List<String> codes, required Object arguments, required String defaultMessage, required String code})
Arguments.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

arguments ↔ Object
getter/setter pair
code ↔ String
getter/setter pair
codes ↔ List<String>
getter/setter pair
defaultMessage ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → Arguments
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited