ErrorRoot class

Constructors

ErrorRoot({required List<String> codes, required List<Arguments> arguments, required String defaultMessage, required String objectName, required String field, required Object rejectedValue, required bool bindingFailure, required String code})
ErrorRoot.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

arguments ↔ List<Arguments>
getter/setter pair
bindingFailure ↔ bool
getter/setter pair
code ↔ String
getter/setter pair
codes ↔ List<String>
getter/setter pair
defaultMessage ↔ String
getter/setter pair
field ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectName ↔ String
getter/setter pair
rejectedValue ↔ Object
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → ErrorRoot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited