GameRoomModel class

Constructors

GameRoomModel({required String roomName, User? pkUser, User? roomCreateUser})
GameRoomModel.fromJson(Map<String, dynamic> res)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pkUser ↔ User?
getter/setter pair
roomCreateUser ↔ User?
getter/setter pair
roomName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

covertFromRoomsApi(String result) → List<GameRoomModel>
获取全部房间的转换