SystemPic class

Constructors

SystemPic({required int id, required String url, required int type, String? intro})
SystemPic.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
intro ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int
getter/setter pair
url ↔ String
getter/setter pair

Methods

clone() → SystemPic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited