Roles class

Constructors

Roles({required int id, required String name, required String description, required int createDate, required int status, required int roleSort})
Roles.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

createDate ↔ int
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
name ↔ String
getter/setter pair
roleSort ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
getter/setter pair

Methods

clone() → Roles
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited