ActivityLinkParam class

Constructors

ActivityLinkParam({String? pid, required String promotionSceneId, String? relationId, String? unionId})
ActivityLinkParam.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pid ↔ String?
getter/setter pair
promotionSceneId ↔ String
getter/setter pair
relationId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unionId ↔ String?
getter/setter pair

Methods

clone() → ActivityLinkParam
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited