CommentParam class

Constructors

CommentParam({String? haopingType, String? goodsId, String? id, String? sort, String? type})
CommentParam.fromJson(Map<String, dynamic> json)
factory

Properties

goodsId ↔ String?
getter/setter pair
haopingType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited