HighCommissionParam class

Constructors

HighCommissionParam({String? cid, required String? pageId, required String? pageSize, String? sort})
HighCommissionParam.fromJson(Map<String, dynamic> json)
factory

Properties

cid ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageId ↔ String?
getter/setter pair
pageSize ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited