NineNineParam class

9快9包邮商品参数

Constructors

NineNineParam({String? pageSize, String? nineCid, String? pageId})
NineNineParam.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nineCid ↔ String?
getter/setter pair
pageId ↔ String?
getter/setter pair
pageSize ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited