WechatParam class

Constructors

WechatParam({String? subcid, String? pre, String? freeshipRemoteDistrict, String? goodsId, String? pageSize, String? sort, required String? pageId, String? cid})
WechatParam.fromJson(Map<String, dynamic> json)
factory

Properties

cid ↔ String?
getter/setter pair
freeshipRemoteDistrict ↔ String?
getter/setter pair
goodsId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageId ↔ String?
getter/setter pair
pageSize ↔ String?
getter/setter pair
pre ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort ↔ String?
getter/setter pair
subcid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited